<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja">
<context>
    <name></name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.cpp" line="29"/>
        <source>(New Phrase)</source>
        <translation>(新しいフレーズ)</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="945"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <location filename="batchtranslationdialog.cpp" line="127"/>
        <source>Batch translated %1 entries</source>
        <translation type="obsolete">%1 項目が一括翻訳されました</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslationdialog.cpp" line="78"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslationdialog.cpp" line="118"/>
        <source>Linguist batch translator</source>
        <translation>Linguist の一括翻訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslationdialog.cpp" line="78"/>
        <source>Searching, please wait...</source>
        <translation>検索しています、お待ちください...</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslationdialog.cpp" line="119"/>
        <source>Batch translated %n entries</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ContextModel</name>
    <message>
        <location filename="contextmodel.cpp" line="176"/>
        <source>Context</source>
        <translation type="obsolete">コンテキスト</translation>
    </message>
    <message>
        <location filename="contextmodel.cpp" line="174"/>
        <source>Done</source>
        <translation type="obsolete">完了</translation>
    </message>
    <message>
        <location filename="contextmodel.cpp" line="178"/>
        <source>Items</source>
        <translation type="obsolete">項目数</translation>
    </message>
</context>
<context>
    <name>EditorPage</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="490"/>
        <source>Source text</source>
        <translation>ソーステキスト</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="821"/>
        <source>Translation (%1)</source>
        <translation>訳 (%1)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="507"/>
        <source>This area shows the source text.</source>
        <translation type="unfinished">この領域はソーステキストを表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="513"/>
        <source>Alternative source text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="523"/>
        <source>This area shows text from an auxillary translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="549"/>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation type="unfinished">この領域は、手助けとなるコメントと、テキストが出てくるコンテキストを表示します。</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="178"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="175"/>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="159"/>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>入力したテキストが次に出てくる箇所を見つけるにはここをクリックします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="136"/>
        <source>Comments</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="133"/>
        <source>Comments and contexts are searched when checked.</source>
        <translation>選択するとコメントとコンテキストが検索されます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="162"/>
        <source>Find Next</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="66"/>
        <source>Find what:</source>
        <translation>検索対象:</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="126"/>
        <source>Match case</source>
        <translation>大文字・小文字の区別</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="85"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="35"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="100"/>
        <source>Source texts</source>
        <translation>ソーステキスト</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="97"/>
        <source>Source texts are searched when checked.</source>
        <translation>選択するとソーステキストが検索されます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="123"/>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>選択すると、たとえば &apos;TeX&apos; と &apos;tex&apos; は異なるものと見なされます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="38"/>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>このウィンドウで翻訳ソースファイル内のテキストを検索できます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="113"/>
        <source>Translations</source>
        <translation>訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="110"/>
        <source>Translations are searched when checked.</source>
        <translation>選択すると訳が検索されます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.ui" line="76"/>
        <source>Type in the text to search for.</source>
        <translation>検索するテキストを入力してください。</translation>
    </message>
</context>
<context>
    <name>FormHolder</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="357"/>
        <source>Preview Form</source>
        <translation>フォームをプレビュー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="616"/>
        <source>About Qt</source>
        <translation>Qt について(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="608"/>
        <source>About Qt Linguist</source>
        <translation>Qt Linguist について(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="477"/>
        <source>&amp;Accelerators</source>
        <translation>アクセラレータの確認(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="670"/>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>フレーズブックにある情報を用いて、全項目を一括翻訳します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="667"/>
        <source>&amp;Batch Translation</source>
        <translation>一括翻訳(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="460"/>
        <source>&amp;Begin from source</source>
        <translation>ソーステキストを元に翻訳(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="43"/>
        <source>&amp;Close Phrase Book</source>
        <translation>フレーズブックを閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="199"/>
        <source>Close this window and exit.</source>
        <translation>このウィンドウを閉じて終了します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="379"/>
        <source>Continue the search where it was left.</source>
        <translation>残りの部分の検索を続けます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="463"/>
        <source>Copies the source text into the translation field.</source>
        <translation>ソーステキストを訳の欄へコピーします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="314"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="300"/>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>選択された訳のテキストをクリップボードにコピーして削除します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="317"/>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>選択された訳のテキストをクリップボードにコピーします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="533"/>
        <source>Create a new phrase book.</source>
        <translation>新しいフレーズブックを作成</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="238"/>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>リリースされたアプリケーションに合う Qt メッセージファイルを、現在のメッセージファイルから作成します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="681"/>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the .ts file.</source>
        <translation>リリースされたアプリケーションにふさわしい Qt メッセージファイルを現在のメッセージファイルから作成します。ファイル名は、.ts ファイルの名前から自動的に決められます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="351"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="466"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="320"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="368"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="550"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="396"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="410"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="536"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="188"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="252"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="202"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="219"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="424"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="438"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="337"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="303"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="286"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="269"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="297"/>
        <source>Cu&amp;t</source>
        <translation>切り取り(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="575"/>
        <source>&amp;Display guesses</source>
        <translation>推測を表示(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="619"/>
        <source>Display information about the Qt toolkit by Trolltech.</source>
        <translation>Trolltech の Qt ツールキットについての情報を表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="449"/>
        <source>&amp;Done and Next</source>
        <translation>完了にして次へ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="147"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="703"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="48"/>
        <source>&amp;Edit Phrase Book</source>
        <translation>フレーズブックを編集(&amp;E)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="491"/>
        <source>&amp;Ending Punctuation</source>
        <translation>末尾の句読点(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="645"/>
        <source>Enter What&apos;s This? mode.</source>
        <translation>ヒントモードに入ります。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="193"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="603"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="382"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="753"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="125"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="692"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="362"/>
        <source>&amp;Find</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="376"/>
        <source>Find &amp;Next</source>
        <translation>次を検索(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="750"/>
        <source>Form Preview Tool</source>
        <translation>フォームプレビューツール</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="736"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="105"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="25"/>
        <source>MainWindow</source>
        <translation>メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="597"/>
        <source>&amp;Manual</source>
        <translation>マニュアル(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="452"/>
        <source>Marks this item as done and moves to the next unfinished item.</source>
        <translation>この項目に完了のマークをつけ、次の未訳の項目へ移動します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="435"/>
        <source>Moves to the next item.</source>
        <translation>次の項目へ移動します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="407"/>
        <source>Moves to the next unfinished item.</source>
        <translation>次の未訳の項目へ移動します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="421"/>
        <source>Moves to the previous item.</source>
        <translation>前の項目へ移動します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="393"/>
        <source>Moves to the previous unfinished item.</source>
        <translation>前の未訳の項目へ移動します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="174"/>
        <source>&amp;New</source>
        <translation>新規(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="530"/>
        <source>&amp;New Phrase Book</source>
        <translation>新しいフレーズブック(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="432"/>
        <source>Ne&amp;xt</source>
        <translation>次へ(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="404"/>
        <source>&amp;Next Unfinished</source>
        <translation>次の未訳へ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="182"/>
        <source>&amp;Open</source>
        <translation>オープン(&amp;O)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="547"/>
        <source>Open a phrase book to assist translation.</source>
        <translation>翻訳の参考にするためにフレーズブックを開きます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="185"/>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Qt 翻訳ソースファイル (TS ファイル) を編集用に開きます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="544"/>
        <source>&amp;Open Phrase Book</source>
        <translation>フレーズブックを開く(&amp;O)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="744"/>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>フォームプレビューを開く／更新する(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="331"/>
        <source>&amp;Paste</source>
        <translation>貼り付け(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="334"/>
        <source>Paste the clipboard text into the translation.</source>
        <translation>クリップボードのテキストを訳に貼り付けます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="505"/>
        <source>&amp;Phrase matches</source>
        <translation>フレーズの一致(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="39"/>
        <source>&amp;Phrases</source>
        <translation>フレーズ(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="519"/>
        <source>Place &amp;Marker Matches</source>
        <translation>&quot;%&quot; の数や数字の一致(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="418"/>
        <source>P&amp;rev</source>
        <translation>前へ(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="390"/>
        <source>&amp;Prev Unfinished</source>
        <translation>前の未訳へ(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="246"/>
        <source>&amp;Print</source>
        <translation>印刷(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="249"/>
        <source>Print a list of all the phrases in the current Qt translation source file.</source>
        <translation>現在の Qt 翻訳ソースファイルの全てのフレーズ一覧を印刷します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="53"/>
        <source>&amp;Print Phrase Book</source>
        <translation>フレーズブックを印刷(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="129"/>
        <source>Re&amp;cently opened files</source>
        <translation>最近開いたファイル(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="280"/>
        <source>&amp;Redo</source>
        <translation>やり直す(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="283"/>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>取り消された編集操作をやり直します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="235"/>
        <source>&amp;Release</source>
        <translation>リリース(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="678"/>
        <source>Release As...</source>
        <translation>名前を付けてリリース...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="659"/>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>検索対象のソーステキストに該当する全項目の訳語を置換します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="561"/>
        <source>&amp;Revert Sorting</source>
        <translation>ソート順序を初期状態に(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="213"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="224"/>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="227"/>
        <source>Save As...</source>
        <translation>名前を付けて保存...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="216"/>
        <source>Save changes made to this Qt translation source file</source>
        <translation>この Qt 翻訳ソースファイルに対して行われた変更を保存します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="230"/>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Qt の翻訳ソースファイルで行われた変更を新しいファイルに保存します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="656"/>
        <source>&amp;Search And Translate</source>
        <translation>検索して訳語を置換(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="365"/>
        <source>Search for some text in the translation source file.</source>
        <translation>翻訳ソースファイルからテキストを検索します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="345"/>
        <source>Select &amp;All</source>
        <translation>すべてを選択(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="348"/>
        <source>Select the whole translation text.</source>
        <translation>訳のテキスト全部を選択します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="578"/>
        <source>Set whether or not to display translation guesses.</source>
        <translation>訳の推測を表示するかどうかを設定します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="592"/>
        <source>Set whether or not to display translation statistics.</source>
        <translation>翻訳の統計を表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="648"/>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="564"/>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>項目のソートの順序をメッセージファイルと同じものに戻します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="589"/>
        <source>&amp;Statistics</source>
        <translation>統計(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="508"/>
        <source>Toggle checking that phrase suggestions are used.</source>
        <translation>フレーズの示唆を使うかどうかのチェックを切り替えます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="480"/>
        <source>Toggle validity checks of accelerators.</source>
        <translation>アクセラレータのチェックを有効にするかどうかを切り替えます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="494"/>
        <source>Toggle validity checks of ending punctuation.</source>
        <translation>末尾の句読点のチェックを有効にするかどうかを切り替えます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="522"/>
        <source>Toggle validity checks of place markers.</source>
        <translation>&quot;%&quot; の数や番号のチェックを行うかどうかを切り替えます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="86"/>
        <source>&amp;Toolbars</source>
        <translation>ツールバー(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="98"/>
        <source>Too&amp;ls</source>
        <translation>ツール(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="714"/>
        <source>Translation</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="114"/>
        <source>&amp;Translation</source>
        <translation>翻訳(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="761"/>
        <source>Translation File &amp;Settings</source>
        <translation>翻訳ファイルの設定(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="263"/>
        <source>&amp;Undo</source>
        <translation>元に戻す(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="266"/>
        <source>Undo the last editing operation performed on the translation.</source>
        <translation>最後に行った編集操作を取り消します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="725"/>
        <source>Validation</source>
        <translation>検証</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="68"/>
        <source>V&amp;alidation</source>
        <translation>検証(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="77"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="81"/>
        <source>Vie&amp;ws</source>
        <translation>表示(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="636"/>
        <source>&amp;What&apos;s This?</source>
        <translation>ヒント(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="642"/>
        <source>What&apos;s This?</source>
        <translation>ヒント</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="769"/>
        <source>Open auxiliary source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/mainwindow.ui" line="777"/>
        <source>Disable auxiliary source</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="55"/>
        <source>backspace</source>
        <translation>バックスペース</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="54"/>
        <source>bell</source>
        <translation>ベル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="58"/>
        <source>carriage return</source>
        <translation>行頭復帰</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="1157"/>
        <source>Guess</source>
        <translation>推測</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="1155"/>
        <source>Guess (%1)</source>
        <translation>推測(%1)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="57"/>
        <source>new line</source>
        <translation>改行</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="56"/>
        <source>new page</source>
        <translation>改ページ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="896"/>
        <source>Phrases</source>
        <translation>フレーズ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="903"/>
        <source>Phrases and guesses:</source>
        <translation>フレーズと推測:</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="332"/>
        <source>sp)</source>
        <translation>スペース)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="60"/>
        <source>tab</source>
        <translation>タブ</translation>
    </message>
    <message>
        <location filename="msgedit.cpp" line="908"/>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation type="obsolete">この領域は、手助けとなるコメントと、テキストが出てくるコンテキストを表示します。</translation>
    </message>
    <message>
        <location filename="msgedit.cpp" line="905"/>
        <source>This area shows the source text.</source>
        <translation type="obsolete">この領域はソーステキストを表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="1185"/>
        <source>This is where you can enter or modify the translation of some source text.</source>
        <translation>ソーステキストの訳を入力したり変更したりできるところです。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="972"/>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>このパネル全体でソーステキストの訳を見たり編集したりすることができます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="1127"/>
        <source>Translation (%1)</source>
        <translation>訳 (%1)</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/messagemodel.cpp" line="328"/>
        <source>Context</source>
        <translation>コンテキスト</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/messagemodel.cpp" line="326"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/messagemodel.cpp" line="330"/>
        <source>Items</source>
        <translation>項目数</translation>
    </message>
</context>
<context>
    <name>MessagesTreeView</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/messagestreeview.cpp" line="65"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
</context>
<context>
    <name>PageCurl</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.h" line="140"/>
        <source>Next unfinished phrase</source>
        <translation>次の未訳のフレーズ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.h" line="149"/>
        <source>Previous unfinished phrase</source>
        <translation>前の未訳のフレーズ</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.cpp" line="107"/>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; を保存できません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="132"/>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>フレーズブックにフレーズを追加するにはここをクリックしてください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="171"/>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックしてください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="145"/>
        <source>Click here to remove the phrase from the phrase book.</source>
        <translation>フレーズブックからフレーズを消去するにはここをクリックしてください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="158"/>
        <source>Click here to save the changes made.</source>
        <translation>変更を保存するにはここをクリックしてください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="168"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="103"/>
        <source>&amp;Definition:</source>
        <translation>定義(&amp;D):</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="28"/>
        <source>Edit Phrase Book</source>
        <translation>フレーズブックを編集</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="129"/>
        <source>&amp;New Phrase</source>
        <translation>新しいフレーズ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.cpp" line="107"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="142"/>
        <source>&amp;Remove Phrase</source>
        <translation>フレーズを消去(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="155"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="73"/>
        <source>S&amp;ource phrase:</source>
        <translation>ソースフレーズ(&amp;S):</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="83"/>
        <source>This is a definition for the source phrase.</source>
        <translation>ソースフレーズの定義です。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="93"/>
        <source>This is the phrase in the source language.</source>
        <translation>ソースの言語のフレーズです。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="63"/>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>ソースフレーズに対応する翻訳先言語のフレーズです。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="31"/>
        <source>This window allows you to add, modify, or delete phrases in a phrase book.</source>
        <translation>このウィンドウでフレーズブックにフレーズを追加、変更、削除できます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.ui" line="53"/>
        <source>&amp;Translation:</source>
        <translation>訳(&amp;T):</translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasemodel.cpp" line="114"/>
        <source>Definition</source>
        <translation>定義</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasemodel.cpp" line="110"/>
        <source>Source phrase</source>
        <translation>ソースフレーズ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasemodel.cpp" line="112"/>
        <source>Translation</source>
        <translation>訳</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/shared/xliff.cpp" line="554"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>QtWindowListMenu</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/qtwindowlistmenu.cpp" line="78"/>
        <source>Cascade</source>
        <translation>カスケード</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/qtwindowlistmenu.cpp" line="80"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/qtwindowlistmenu.cpp" line="82"/>
        <source>Close All</source>
        <translation>すべて閉じる</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/qtwindowlistmenu.cpp" line="77"/>
        <source>Tile</source>
        <translation>タイル</translation>
    </message>
</context>
<context>
    <name>SourceTextEdit</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="350"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="353"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="351"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="352"/>
        <source>Select &amp;All</source>
        <translation>すべてを選択(&amp;A)</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="204"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="184"/>
        <source>Characters (with spaces):</source>
        <translation>文字(スペースつき):</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="174"/>
        <source>Characters:</source>
        <translation>文字:</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="61"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="114"/>
        <source>Source</source>
        <translation>ソース</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="28"/>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="104"/>
        <source>Translation</source>
        <translation>訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/statistics.ui" line="144"/>
        <source>Words:</source>
        <translation>語:</translation>
    </message>
</context>
<context>
    <name>TrPreviewTool</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="42"/>
        <source>&lt;No Translation&gt;</source>
        <translation>&lt;翻訳ファイルなし&gt;</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="298"/>
        <source>About </source>
        <translation> について</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="157"/>
        <source>Could not load form file(s):
</source>
        <translation>フォームファイルをロードできませんでした:
</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="250"/>
        <source>Could not load translation file:
</source>
        <translation>翻訳ファイルをロードできませんでした:
</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="273"/>
        <source>Could not reload translation file(s):
</source>
        <translation>翻訳ファイルをリロードできませんでした:
</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="32"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="244"/>
        <source>Load Translation</source>
        <translation>翻訳ファイルをロード</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="121"/>
        <source>Open Forms</source>
        <translation>フォームを開く</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="284"/>
        <source>Qt Translation Preview Tool: Warning</source>
        <translation>Qt 翻訳プレビューツール: 警告</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="246"/>
        <source>Translation files (*.qm);;All files (*.*)</source>
        <translation>翻訳ファイル (*.qm);;全てのファイル (*.*)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="123"/>
        <source>User interface form files (*.ui);;All files (*.*)</source>
        <translation>ユーザインタフェースファイル (*.ui);;全てのファイル (*.*)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.cpp" line="37"/>
        <source>Windows</source>
        <translation>ウィンドウ</translation>
    </message>
</context>
<context>
    <name>TrPreviewToolClass</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="148"/>
        <source>About</source>
        <translation>について</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="153"/>
        <source>About Qt</source>
        <translation>Qt について</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="143"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="138"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="59"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="85"/>
        <source>Forms</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="52"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="127"/>
        <source>&amp;Load Translation...</source>
        <translation>翻訳ファイルをロード(&amp;L)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="119"/>
        <source>&amp;Open Form...</source>
        <translation>フォームを開く(&amp;O)...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="27"/>
        <source>Qt Translation Preview Tool</source>
        <translation>Qt 翻訳プレビューツール</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="135"/>
        <source>&amp;Reload Translations</source>
        <translation>翻訳ファイルをリロード(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="41"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/previewtool/trpreviewtool.ui" line="45"/>
        <source>&amp;Views</source>
        <translation>表示(&amp;V)</translation>
    </message>
</context>
<context>
    <name>TrWindow</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="916"/>
        <source> Open Source Edition</source>
        <translation> オープンソース版</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="830"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1013"/>
        <source>%1 - %2%3</source>
        <translation>%1 - %2%3</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="804"/>
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>%n 項目のフレーズがロードされました。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="322"/>
        <source>%n source phrase(s) loaded.</source>
        <translation>
            <numerusform>%n 個のソースフレーズがロードされました。</numerusform>
        </translation>
    </message>
    <message>
        <location filename="trwindow.cpp" line="900"/>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;%2&lt;/p&gt;&lt;p&gt;Copyright (C) 2000-2006 Trolltech ASA. All rights reserved.&lt;/p&gt;&lt;p&gt;The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist は、Qt アプリケーションの翻訳を行うツールです。&lt;/p&gt;&lt;p&gt;%2&lt;/p&gt;&lt;p&gt;Copyright (C) 2000-2006 Trolltech ASA. 全ての権利は保護されています。&lt;/p&gt;&lt;p&gt;このプログラムは、「設計」、「市場性」および「特定の目的への適合性」も含む、あらゆる種類の「保証がなく」、「そのままで」提供されます。&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="763"/>
        <source>A file called &apos;%1&apos; already exists.  Please choose another name.</source>
        <translation>&apos;%1&apos; というファイルはすでに存在します。別の名前を選んでください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1779"/>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>&apos;%1&apos; についてのフレーズブックの示唆を無視しています。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1739"/>
        <source>Accelerator possibly missing in translation.</source>
        <translation>訳にアクセラレータが欠けています。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1734"/>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation>訳に余分なアクセラレータがついています。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1625"/>
        <source>Allow you to add, modify, or delete phrases of this phrase book.</source>
        <translation>フレーズブックにフレーズを追加、変更、削除できます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1644"/>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; を作成できません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="732"/>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>文字列 &apos;%1&apos; が見つかりません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="372"/>
        <source>Cannot open &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; をオープンできません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1614"/>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; から読み出せません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="434"/>
        <source>Cannot save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; を保存できません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1620"/>
        <source>Close this phrase book.</source>
        <translation>このフレーズブックを閉じます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="197"/>
        <source>Context</source>
        <translation>コンテキスト</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="459"/>
        <source>Context: %1</source>
        <translation>コンテキスト: %1</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="755"/>
        <source>Create New Phrase Book</source>
        <translation>新しいフレーズブックを作成</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1488"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1503"/>
        <source>Display information about %1.</source>
        <translation>%1 についての情報を表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1502"/>
        <source>Display the manual for %1.</source>
        <translation>%1 のマニュアルを表示します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="978"/>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>&apos;%1&apos; を保存しますか?</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1536"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1529"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="432"/>
        <source>File created.</source>
        <translation>ファイルが作成されました。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="390"/>
        <source>File saved.</source>
        <translation>ファイルが保存されました。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="475"/>
        <source>finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1555"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="292"/>
        <source>Loading...</source>
        <translation>ロードしています...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1487"/>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="235"/>
        <source>MOD</source>
        <translation>変更されています</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1309"/>
        <source>No untranslated phrases left.</source>
        <translation>未訳のフレーズは残っていません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="481"/>
        <source>obsolete</source>
        <translation>このバージョンでは使われていない</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="798"/>
        <source>Open Phrase Book</source>
        <translation>フレーズブックを開く</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="770"/>
        <source>Phrase book created.</source>
        <translation>フレーズブックが作成されました。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1630"/>
        <source>Print the entries of the phrase book.</source>
        <translation>フレーズブックの見出し語を印刷します。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="881"/>
        <source>Printing aborted</source>
        <translation>印刷中止</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="879"/>
        <source>Printing completed</source>
        <translation>印刷完了</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="859"/>
        <source>Printing...</source>
        <translation>印刷中...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="873"/>
        <source>Printing... (page %1)</source>
        <translation>印刷中... (%1 ページ)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1987"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1013"/>
        <source>Qt Linguist by Trolltech</source>
        <translation>Trolltech の Qt Linguist</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="414"/>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>リリースされたアプリケーション用の Qt メッセージファイル (*.qm)
すべてのファイル (*)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="799"/>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Qt フレーズブック (*.qph)
すべてのファイル (*)</translation>
    </message>
    <message>
        <location filename="trwindow.cpp" line="363"/>
        <source>Qt translation source (*.ts)
All files (*)</source>
        <translation type="obsolete">Qt 翻訳ソースファイル (*.ts)
すべてのファイル (*)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="413"/>
        <source>Release</source>
        <translation>リリース</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="606"/>
        <source>Search wrapped.</source>
        <translation>検索が一通り終わりました。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1987"/>
        <source>There was a problem in the preparation of form preview.</source>
        <translation>フォームのプレビューの準備中に問題が発生しました。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="259"/>
        <source>This panel lists the source contexts.</source>
        <translation>このパネルではソースのコンテキストを一覧表示しています。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="933"/>
        <source>This program is licensed to you under the terms of the Qt Commercial License Agreement. For details, see the file LICENSE that came with this software distribution.</source>
        <translation>このプログラムは、Qt 商用ライセンス契約書の定める条件の下であなたの利用が認められています。詳細は、ソフトウェアと一緒に配布される LICENSE ファイルを参照してください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="929"/>
        <source>This version of Qt Linguist is part of the Qt Open Source Edition, for use in the development of Open Source applications. Qt is a comprehensive C++ framework for cross-platform application development.&lt;br/&gt;&lt;br/&gt;You need a commercial Qt license for development of proprietary (closed source) applications. Please see &lt;tt&gt;http://www.trolltech.com/company/model.html&lt;/tt&gt; for an overview of Qt licensing.</source>
        <translation>このバージョンの Qt Linguist は、 オープンソースアプリケーションを開発するための Qt オープンソース版の一部です。Qt は、クロスプラットフォームなアプリケーションを開発するための包括的な C++ のフレームワークです。&lt;br/&gt;&lt;br/&gt;独占的な（ソースが隠された）アプリケーションを開発するには、Qt の商用ライセンスが必要です。Qt のライセンスの概要については &lt;tt&gt;http://www.trolltech.com/company/model.html&lt;/tt&gt; をご覧ください。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="689"/>
        <source>Translate</source>
        <translation>翻訳</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="690"/>
        <source>Translated %n entries to &apos;%1&apos;</source>
        <translation>
            <numerusform>%n 項目を &apos;%1&apos; に翻訳しました</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1542"/>
        <source>Translation</source>
        <translation>訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1752"/>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation>訳がソーステキストと同じ句読点で終わっていません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1828"/>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation>訳語にはソーステキストと同じ数の &quot;%&quot; がありません。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="478"/>
        <source>unresolved</source>
        <translation>未解決</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1548"/>
        <source>Validation</source>
        <translation>検証</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="914"/>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="1485"/>
        <source>&amp;Window</source>
        <translation>ウィンドウ(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="302"/>
        <source>%1 translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="399"/>
        <source>Qt translation source (*.ts)
XLIFF localization file (*.xlf)
All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="350"/>
        <source>Qt alternative translation source (*.ts)
XLIFF localization file (*.xlf)
All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="367"/>
        <source>Loading alternative translation...</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="376"/>
        <source>%n alternative translation(s) loaded.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="379"/>
        <source>Existing %1 translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="943"/>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;%2&lt;/p&gt;&lt;p&gt;Copyright (C) 2000-2008 Trolltech ASA. All rights reserved.&lt;/p&gt;&lt;p&gt;The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="219"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="216"/>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="186"/>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>入力したテキストが次に出てくる箇所を見つけるにはここをクリックします。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="189"/>
        <source>Find Next</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="99"/>
        <source>Find &amp;source text:</source>
        <translation>ソーステキストを検索(&amp;S):</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="144"/>
        <source>Mark new translation as &amp;finished</source>
        <translation>新しく翻訳した項目を完了にする(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="137"/>
        <source>Match &amp;case</source>
        <translation>大文字・小文字の区別(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="31"/>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="128"/>
        <source>Search options</source>
        <translation>検索オプション</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="134"/>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>これを選択すると、たとえば &apos;TeX&apos; と &apos;tex&apos; は異なるものと見なされます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="34"/>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>このウィンドウで翻訳ソースファイル内のテキストを検索できます。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="202"/>
        <source>Translate</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="209"/>
        <source>Translate All</source>
        <translation>すべて翻訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="109"/>
        <source>&amp;Translate to:</source>
        <translation>訳語(&amp;T):</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translatedialog.ui" line="119"/>
        <source>Type in the text to search for.</source>
        <translation>検索するテキストを入力してください。</translation>
    </message>
</context>
<context>
    <name>TranslationSettings</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="53"/>
        <source>Country</source>
        <translation type="obsolete">国</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="40"/>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="13"/>
        <source>Qt Linguist - Translation file settings</source>
        <translation>Qt Linguist - 翻訳ファイルの設定</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="25"/>
        <source>Target language</source>
        <translation>翻訳先の言語</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="53"/>
        <source>Country/Region</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettingsdialog.cpp" line="34"/>
        <source>Any Country</source>
        <translation>指定しない</translation>
    </message>
</context>
<context>
    <name>databaseTranslationDialog</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="197"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="132"/>
        <source>Move down</source>
        <translation>下に移動</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="125"/>
        <source>Move up</source>
        <translation>上に移動</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="59"/>
        <source>Only translate entries with no translation</source>
        <translation>訳語がない項目だけを翻訳する</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="47"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="90"/>
        <source>Phrase book preference</source>
        <translation>フレーズブックの優先度</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="27"/>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - 一括翻訳</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="190"/>
        <source>&amp;Run</source>
        <translation>実行(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="69"/>
        <source>Set translated entries to finished</source>
        <translation>翻訳された項目を完了にする</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/batchtranslation.ui" line="156"/>
        <source>The batch translator will search through the selected phrasebooks in the order given above.</source>
        <translation>一括翻訳機能は、上記で指定された順にフレーズブックを検索します。</translation>
    </message>
</context>
</TS>
